@@ -21,30 +21,28 @@ public:
     /**
      * @note When adding a new calendar system, \s_calendarMap should also be updated.
      */
-    enum System {
+    enum System : int {
         Gregorian = static_cast<int>(QCalendar::System::Gregorian),
 #ifndef QT_BOOTSTRAPPED
         Julian = static_cast<int>(QCalendar::System::Julian),
         Milankovic = static_cast<int>(QCalendar::System::Milankovic),
-#endif
-#if QT_CONFIG(jalalicalendar)
-        Jalali = static_cast<int>(QCalendar::System::Jalali),
-#endif
-#if QT_CONFIG(islamiccivilcalendar)
-        IslamicCivil = static_cast<int>(QCalendar::System::IslamicCivil),
 #endif
         Chinese = static_cast<int>(QCalendar::System::Last) + 1, // QTBUG-89824: QCalendar doesn't support Chinese calendar system
         Indian, // QCalendar doesn't support India calendar system
         Hebrew,
+        Jalali, // Persian
+        Islamic, // Astronomical
+        IslamicCivil,
+        IslamicUmalqura,
     };
     Q_ENUM(System)
 };
 Q_DECLARE_METATYPE(CalendarSystem)
 
 struct CalendarSystemItem {
-    CalendarSystem::System system;
-    QString id;
-    QString text;
+    const CalendarSystem::System system;
+    const QString id;
+    const QString text;
 };
 
 // clang-format off
@@ -61,9 +59,17 @@ static const std::map<QString /* id */, CalendarSystemItem> s_calendarMap{
         QStringLiteral("Jalali"),
         {CalendarSystem::Jalali, QStringLiteral("Jalali"), i18ndc("plasma_calendar_alternatecalendar", "@item:inlist", "The Solar Hijri Calendar (Persian)")}
     },
+    {
+        QStringLiteral("Islamic"),
+        {CalendarSystem::Islamic, QStringLiteral("Islamic"), i18ndc("plasma_calendar_alternatecalendar", "@item:inlist See https://cldr.unicode.org/development/development-process/design-proposals/islamic-calendar-types for more details", "Islamic Calendar (Astronomical)")}
+    },
     {
         QStringLiteral("IslamicCivil"),
-        {CalendarSystem::IslamicCivil, QStringLiteral("IslamicCivil"), i18ndc("plasma_calendar_alternatecalendar", "@item:inlist", "The Islamic Civil Calendar")}
+        {CalendarSystem::IslamicCivil, QStringLiteral("IslamicCivil"), i18ndc("plasma_calendar_alternatecalendar", "@item:inlist See https://cldr.unicode.org/development/development-process/design-proposals/islamic-calendar-types for more details", "The Islamic Civil Calendar (Tabular)")}
+    },
+    {
+        QStringLiteral("IslamicUmalqura"),
+        {CalendarSystem::IslamicUmalqura, QStringLiteral("IslamicUmalqura"), i18ndc("plasma_calendar_alternatecalendar", "@item:inlist See https://cldr.unicode.org/development/development-process/design-proposals/islamic-calendar-types for more details", "Islamic Calendar (Umm al-Qura)")}
     },
     {
         QStringLiteral("Chinese"),
